@@ -126,7 +126,8 @@ get '/edit_model' => sub ($c) {
   my $synth = Synth::Config->new(model => $v->param('model'));
   my $model_file = SETTINGS . $synth->model . '.dat';
   my $specs = -e $model_file ? retrieve($model_file) : undef;
-  my $groups = join ',', $specs->{group}->@*;
+  my $groups;
+  $groups = join ',', $specs->{group}->@* if exists $specs->{group};
   $c->render(
     template   => 'edit_model',
     model      => $v->param('model'),
@@ -148,14 +149,14 @@ get '/remove' => sub ($c) {
   my $synth = Synth::Config->new(model => $v->param('model'));
   if ($v->param('id')) {
     $synth->remove_setting(id => $v->param('id'));
-    $c->flash(message => 'Remove successful');
+    $c->flash(message => 'Remove setting successful');
     return $c->redirect_to($c->url_for('index')->query(model => $v->param('model'), name => $v->param('name')));
   }
   elsif ($synth->model) {
     $synth->remove_model;
     my $model_file = Mojo::File->new(SETTINGS . $synth->model . '.dat');
     $model_file->remove;
-    $c->flash(message => 'Remove successful');
+    $c->flash(message => 'Remove model successful');
     return $c->redirect_to('index');
   }
 } => 'remove';
@@ -246,7 +247,7 @@ post '/update' => sub ($c) {
     unit       => $v->param('unit'),
     is_default => $v->param('is_default'),
   );
-  $c->flash(message => 'Update successful');
+  $c->flash(message => 'Update setting successful');
   $c->redirect_to($c->url_for('edit')->query(
     id         => $id,
     name       => $v->param('name'),
@@ -291,7 +292,7 @@ __DATA__
     <select name="name" id="name" class="form-select">
       <option value="">Setting name...</option>
 % for my $n (@$names) {
-      <option value="<%= $n %>" <%= $names && $n eq $name ? 'selected' : '' %>><%= ucfirst $n %></option>
+      <option value="<%= $n %>" <%= $names && $name && $n eq $name ? 'selected' : '' %>><%= ucfirst $n %></option>
 % }
     </select>
   </div>
@@ -313,14 +314,15 @@ __DATA__
 <p></p>
 <div class="row">
   <div class="col">
-    <button type="submit" class="btn btn-primary"><i class="fa-solid fa-magnifying-glass"></i> Search</button>
+    <button type="submit" id="search" class="btn btn-primary"><i class="fa-solid fa-magnifying-glass"></i> Search</button>
 % if ($model) {
-    <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $group) %>" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
+    <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $group) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
 % }
-    <a href="<%= url_for('model') %>" class="btn btn-success"><i class="fa-solid fa-database"></i> New model</a>
+    <a href="<%= url_for('model') %>" class="btn btn-success" id="new_model"><i class="fa-solid fa-database"></i> New model</a>
 % if ($model) {
-    <a href="<%= url_for('edit_model')->query(model => $model) %>" class="btn btn-success"><i class="fa-solid fa-pencil"></i> Edit model</a>
-    <a href="<%= url_for('remove')->query(model => $model) %>" class="btn btn-danger" onclick="if(!confirm('Remove model?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove model</a>
+    <a href="<%= url_for('edit_model')->query(model => $model) %>" id="edit_model" class="btn btn-success"><i class="fa-solid fa-pencil"></i> Edit model</a>
+
+    <a href="<%= url_for('remove')->query(model => $model) %>" id="remove_model" class="btn btn-danger" onclick="if(!confirm('Remove model?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove model</a>
 % }
   </div>
 </div>
@@ -379,9 +381,9 @@ __DATA__
 <div class="row">
   <div class="col">
 % unless ($group_list) {
-    <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Add model</button>
+    <button type="submit" id="new_model" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Add model</button>
 % }
-    <a href="<%= url_for('index') %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
+    <a href="<%= url_for('index') %>" id="cancel" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
   </div>
 </div>
 </form>
@@ -420,14 +422,14 @@ __DATA__
   <input type="hidden" name="model" value="<%= $model %>">
   <input type="hidden" name="groups" value="<%= $groups %>">
 % for my $g (@$group_list) {
-  <label for="<%= $g %>_param"><%= $g %>:</label>
-  <input type="text" name="group" id="<%= $g %>_param" value="<%= join ',', $specs->{$g}->@* %>" class="form-control" placeholder="<%= ucfirst $g %> parameter1, param2, etc.">
+  <label for="<%= $g %>"><%= $g %>:</label>
+  <input type="text" name="group" id="<%= $g %>" value="<%= join ',', $specs->{$g}->@* %>" class="form-control" placeholder="<%= $g %> parameter1, param2, etc.">
   <p></p>
 % }
   <div class="row">
     <div class="col">
       <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Update model</button>
-      <a href="<%= url_for('index')->query(model => $model) %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
+      <a href="<%= url_for('index')->query(model => $model) %>" id="cancel" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
     </div>
   </div>
 </form>
@@ -494,9 +496,9 @@ __DATA__
   <p></p>
   <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Submit</button>
 % if ($id) {
-  <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove</a>
+  <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" id="remove" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove</a>
 % }
-  <a href="<%= url_for('index')->query(model => $model, name => $name, group => $selected->{group}) %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
+  <a href="<%= url_for('index')->query(model => $model, name => $name, group => $selected->{group}) %>" id="cancel" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
 </form>
 <script>
 $(document).ready(function() {
